HashCell

Struct HashCell 

pub struct HashCell<K, const D: usize>
where K: Eq + Hash,
{ /* private fields */ }
Bucket sort points into cubes with HashMap-backed storage

See VecCell for a complete description of the algorithm. Use VecCell for dense, bounded collections of points. Use HashMap for sparse and/or unbounded collections of points.

Examples

The default HashCell set both the nominal and maximum search radii to 1.0.

use hoomd_spatial::HashCell;

let hash_cell = HashCell::<usize, 3>::default();

Use the builder API to set any or all parameters:

use hoomd_spatial::HashCell;

let hash_cell = HashCell::<usize, 3>::builder()
    .nominal_search_radius(2.5.try_into()?)
    .maximum_search_radius(7.5)
    .build();

Implementations

Source

impl<K, const D: usize> HashCell<K, D>
where K: Copy + Eq + Hash,

pub fn shrink_to_fit(&mut self)

Remove excess capacity from dynamically allocated arrays.

pub fn builder() -> HashCellBuilder<K, D>

Construct a HashCell builder.

Use the builder to set any or all parameters and construct a HashCell.

Example
use hoomd_spatial::HashCell;

let hash_cell = HashCell::<usize, 3>::builder()
    .nominal_search_radius(2.5.try_into()?)
    .maximum_search_radius(7.5)
    .build();