VecCell

Struct VecCell 

pub struct VecCell<K, const D: usize>
where K: Eq + Hash,
{ /* private fields */ }
Bucket sort points into cubes with Vec-backed storage

VecCell is a spatial data structure that can efficiently update one point at a time (see PointUpdate) and find all points that are near a position in space (see PointsNearBall).

Points are stored in VecCell by key. The caller can choose a generic key type K appropriately. For example, K could be usize and map to an array index. Or it could be an enum that distinguishes between primary and ghost site positions.

Internally, VecCell stores a D-dimensional vector of cells that partition space. Each bucket is a hypercube with an edge length equal to the nominal search radius. When searching for points near a position in space, VecCell first determines which bucket that point is in. Then it iterates over all the keys in all the cells within the given search radius. To perform this iteration efficiently, VecCell pre-computes a set of stencils up to the given maximum search radius given at const

In systems with low density fluctuations, the time complexity of VecCell is O(1). More generally, and important when density fluctuations are present, the time complexity scales with the maximum number of points in any of the cells.

VecCell performs best when the search radius is equal to the nominal search radius. In that case, 2D searches loop over 9 cells and 3D searches loop over 27. The caller must filter the output of this iteration because the resulting hypercube covers more volume than the given hypersphere. When searching with a radius larger than the nominal, many more cells must be iterated leading to slower performance. At the same time, the stencil covers less excess volume and therefore fewer points must be filtered.

VecCell stores each cell at a unique index backed by storage in Vec. This performs very well in dense, compact systems. However, the memory utilization scales with the volume of the cube that spans from the most negative point to the most positive point. In dilute systems, VecCell can therefore waste a lot of memory storing empty cells. Use HashCell and occasionally call its shrink_to_fit method to limit the memory required to model dilute systems.

Examples

The default VecCell set both the nominal and maximum search radii to 1.0.

use hoomd_spatial::VecCell;

let vec_cell = VecCell::<usize, 3>::default();

Use the builder API to set any or all parameters:

use hoomd_spatial::VecCell;

let vec_cell = VecCell::<usize, 3>::builder()
    .nominal_search_radius(2.5.try_into()?)
    .maximum_search_radius(7.5)
    .build();

Implementations

Source

impl<K, const D: usize> VecCell<K, D>
where K: Copy + Eq + Hash,

pub fn builder() -> VecCellBuilder<K, D>

Construct a VecCell builder.

Use the builder to set any or all parameters and construct a VecCell.

Example
use hoomd_spatial::VecCell;

let vec_cell = VecCell::<usize, 3>::builder()
    .nominal_search_radius(2.5.try_into()?)
    .maximum_search_radius(7.5)
    .build();
pub fn shrink_to_fit(&mut self)

Remove excess capacity from dynamically allocated arrays.

At this time, shrink_to_fit only reduces the memory utilized by the cell contents. It does not shrink the D-dimensional storage to match the range spanned by points currently in the data structure.