VecCellBuilder

Struct VecCellBuilder 

pub struct VecCellBuilder<K, const D: usize> { /* private fields */ }
Construct a VecCell with given parameters.

Example

use hoomd_spatial::VecCell;

let vec_cell = VecCell::<usize, 3>::builder()
    .nominal_search_radius(2.5.try_into()?)
    .maximum_search_radius(7.5)
    .build();

Implementations

Source

impl<K, const D: usize> VecCellBuilder<K, D>
where K: Copy + Eq + Hash,

pub fn nominal_search_radius(self, nominal_search_radius: PositiveReal) -> Self

Choose the most commonly used search radius.

VecCell performs the best when searching for points within the nominal search radius of a given position.

Example
use hoomd_spatial::VecCell;

let vec_cell = VecCell::<usize, 3>::builder()
    .nominal_search_radius(2.5.try_into()?)
    .build();
pub fn maximum_search_radius(self, maximum_search_radius: f64) -> Self

Choose the largest search radius.

The maximum radius is rounded up to the nearest integer multiple of the nominal search radius. VecCell will panic when asked to search for points within a radius larger than the maximum.

Example
use hoomd_spatial::VecCell;

let vec_cell = VecCell::<usize, 3>::builder()
    .nominal_search_radius(2.5.try_into()?)
    .maximum_search_radius(7.5)
    .build();
pub fn build(self) -> VecCell<K, D>

Construct the VecCell with the chosen parameters.

Example
use hoomd_spatial::VecCell;

let vec_cell = VecCell::<usize, 3>::builder()
    .nominal_search_radius(2.5.try_into()?)
    .maximum_search_radius(7.5)
    .build();