WithSearchRadius

Trait WithSearchRadius 

pub trait WithSearchRadius {
    // Required method
    fn with_search_radius(radius: PositiveReal) -> Self;
}
Construct a spatial data structure capable of searching up to the given radius.

Required Methods

fn with_search_radius(radius: PositiveReal) -> Self

Construct a spatial data structure that can search at least as far as the given radius.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<K> WithSearchRadius for AllPairs<K>
where K: Copy + Eq + Hash,

Source

impl<K, const D: usize> WithSearchRadius for HashCell<K, D>
where K: Copy + Eq + Hash,

Source

impl<K, const D: usize> WithSearchRadius for VecCell<K, D>
where K: Copy + Eq + Hash,